@@ -32,7 +32,6 @@ import textwrap
 
 import json
 import pkg_resources
-import six
 import yaml
 
 
@@ -119,7 +118,7 @@ def _format_defaults(opt):
             default_str = str(opt.default)
         elif isinstance(opt, (cfg.ListOpt, cfg._ConfigFileOpt,
                               cfg._ConfigDirOpt)):
-            default_str = ','.join(six.text_type(d) for d in opt.default)
+            default_str = ','.join(str(d) for d in opt.default)
         elif isinstance(opt, cfg.DictOpt):
             sorted_items = sorted(opt.default.items(),
                                   key=operator.itemgetter(0))
@@ -131,8 +130,8 @@ def _format_defaults(opt):
 
     results = []
     for default_str in defaults:
-        if not isinstance(default_str, six.text_type):
-            default_str = six.text_type(default_str)
+        if not isinstance(default_str, str):
+            default_str = str(default_str)
         if default_str.strip() != default_str:
             default_str = '"%s"' % default_str
         results.append(default_str)
@@ -201,7 +200,7 @@ class _OptFormatter(object):
             return '<None>'
         elif choice == '':
             return "''"
-        return six.text_type(choice)
+        return str(choice)
 
     def format_group(self, group_or_groupname):
         """Format the description of a group header to the output file
@@ -255,10 +254,10 @@ class _OptFormatter(object):
         lines = self._format_help(help_text)
 
         if getattr(opt.type, 'min', None) is not None:
-            lines.append('# Minimum value: %d\n' % opt.type.min)
+            lines.append('# Minimum value: {}\n'.format(opt.type.min))
 
         if getattr(opt.type, 'max', None) is not None:
-            lines.append('# Maximum value: %d\n' % opt.type.max)
+            lines.append('# Maximum value: {}\n'.format(opt.type.max))
 
         if getattr(opt.type, 'choices', None):
             lines.append('# Possible values:\n')
@@ -357,12 +356,12 @@ class _OptFormatter(object):
         """
         self.output_file.write(s)
 
-    def writelines(self, l):
+    def writelines(self, lines):
         """Write an arbitrary sequence of strings to the output file.
 
-        :param l: a list of arbitrary strings
+        :param lines: a list of arbitrary strings
         """
-        self.output_file.writelines(l)
+        self.output_file.writelines(lines)
 
 
 def _cleanup_opts(read_opts):
