@@ -12,13 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
 import sys
 import textwrap
+from unittest import mock
 
 import fixtures
-import mock
 from oslotest import base
-from six import moves
 import tempfile
 import testscenarios
 
@@ -437,7 +437,7 @@ class GeneratorTestCase(base.BaseTestCase):
 ''')),
         ('choices_opt',
          dict(opts=[('test', [(None, [opts['choices_opt']])])],
-              expected='''[DEFAULT]
+              expected="""[DEFAULT]
 
 #
 # From test
@@ -451,7 +451,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # b - <No description provided>
 # c - <No description provided>
 #choices_opt = a
-''')),
+""")),
         ('deprecated opt without deprecated group',
          dict(opts=[('test',
                      [(groups['foo'],
@@ -852,13 +852,13 @@ class GeneratorTestCase(base.BaseTestCase):
 # string with bad default (string value)
 #string_type_with_bad_default = 4096
 ''')),
-         ('str_opt_str_group',
+        ('str_opt_str_group',
          dict(opts=[('test', [('foo',
                                [opts['str_opt']]),
                               (groups['foo'],
                                [opts['int_opt']])]),
                     ('foo', [('foo',
-                               [opts['bool_opt']])])],
+                              [opts['bool_opt']])])],
               expected='''[DEFAULT]
 
 
@@ -888,7 +888,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # Maximum value: 20
 #int_opt = 10
 ''')),
-         ('opt_str_opt_group',
+        ('opt_str_opt_group',
          dict(opts=[('test', [(groups['foo'],
                                [opts['int_opt']]),
                               ('foo',
@@ -924,7 +924,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # a string (string value)
 #str_opt = foo bar
 ''')),
-         ('opt_with_DeprecatedOpt',
+        ('opt_with_DeprecatedOpt',
          dict(opts=[('test', [(None, [opts['opt_with_DeprecatedOpt']])])],
               expected='''[DEFAULT]
 
@@ -963,7 +963,7 @@ class GeneratorTestCase(base.BaseTestCase):
 
     def _capture_stream(self, stream_name):
         self.useFixture(fixtures.MonkeyPatch("sys.%s" % stream_name,
-                                             moves.StringIO()))
+                                             io.StringIO()))
         return getattr(sys, stream_name)
 
     def _capture_stdout(self):
@@ -1103,7 +1103,7 @@ class DriverOptionTestCase(base.BaseTestCase):
         # Initialize the generator to produce YAML output to a buffer.
         generator.register_cli_opts(self.conf)
         self.config(namespace=['test_generator'], format_='yaml')
-        stdout = moves.StringIO()
+        stdout = io.StringIO()
 
         # Generate the output and parse it back to a data structure.
         generator.generate(self.conf, output_file=stdout)
@@ -1609,7 +1609,7 @@ class GeneratorAdditionalTestCase(base.BaseTestCase):
 class GeneratorMutableOptionTestCase(base.BaseTestCase):
 
     def test_include_message(self):
-        out = moves.StringIO()
+        out = io.StringIO()
         opt = cfg.StrOpt('foo', help='foo option', mutable=True)
         gen = build_formatter(out)
         gen.format(opt, 'group1')
@@ -1620,7 +1620,7 @@ class GeneratorMutableOptionTestCase(base.BaseTestCase):
         )
 
     def test_do_not_include_message(self):
-        out = moves.StringIO()
+        out = io.StringIO()
         opt = cfg.StrOpt('foo', help='foo option', mutable=False)
         gen = build_formatter(out)
         gen.format(opt, 'group1')
@@ -1854,7 +1854,7 @@ class HostAddressTestCase(base.BaseTestCase):
         config = [("namespace", [("alpha", self.opts)])]
         groups = generator._get_groups(config)
 
-        out = moves.StringIO()
+        out = io.StringIO()
         formatter = build_formatter(out)
         generator._output_opts(formatter, 'alpha', groups.pop('alpha'))
         result = out.getvalue()
@@ -1871,5 +1871,6 @@ class HostAddressTestCase(base.BaseTestCase):
         ''').lstrip()
         self.assertEqual(expected, result)
 
+
 GeneratorTestCase.generate_scenarios()
 MachineReadableGeneratorTestCase.generate_scenarios()
